[NFC][XCOFF][AIX] Rename ControlSections to CsectGroup

The name of ControlSections is not expressive enough to convey what they really are.
CsectGroup can better communicate the concept of grouping csects together since they have similar property.

Reviewer: daltenty

Differential Revision: https://reviews.llvm.org/D69001

git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@375021 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/MC/XCOFFObjectWriter.cpp b/lib/MC/XCOFFObjectWriter.cpp
index e383e7e..353c210 100644
--- a/lib/MC/XCOFFObjectWriter.cpp
+++ b/lib/MC/XCOFFObjectWriter.cpp
@@ -115,7 +115,7 @@
   // (approximately) the same storage mapping class. For example all the csects
   // with a storage mapping class of `xmc_pr` will get placed into the same
   // container.
-  using ControlSections = std::deque<ControlSection>;
+  using CsectGroup = std::deque<ControlSection>;
 
   support::endian::Writer W;
   std::unique_ptr<MCXCOFFObjectTargetWriter> TargetObjectWriter;
@@ -129,11 +129,11 @@
   Section Text;
   Section BSS;
 
   // ControlSections. These store the csects which make up different parts of
   // the sections. Should have one for each set of csects that get mapped into
   // the same section and get handled in a 'similar' way.
-  ControlSections ProgramCodeCsects;
-  ControlSections BSSCsects;
+  CsectGroup ProgramCodeCsects;
+  CsectGroup BSSCsects;
 
   uint32_t SymbolTableEntryCount = 0;
   uint32_t SymbolTableOffset = 0;
@@ -129,11 +129,11 @@
   Section BSS;
 
-  // ControlSections. These store the csects which make up different parts of
+  // CsectGroups. These store the csects which make up different parts of
   // the sections. Should have one for each set of csects that get mapped into
   // the same section and get handled in a 'similar' way.